Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type Configuration ¶
type Configuration struct {
BaseURL string `json:"base-url"`
SSL bool `json:"ssl,omitempty"`
SSLDomain string `json:"ssl-domain,omitempty"`
Methods []MethodsConfig `json:"methods"`
}
Configuration type representing the .json config file
var Config Configuration
Config var with the configuration parsed from the .json file
func LoadConfig ¶
func LoadConfig(content string) Configuration
LoadConfig loads the content (as JSON) into an instance of Configuration type
func LoadConfigFile ¶
func LoadConfigFile(filePath string) Configuration
LoadConfigFile loads the config file into an instance of Configuration type
type MethodsConfig ¶
type MethodsConfig struct {
Name string `json:"name"`
ProxyTo []string `json:"proxy-to"`
RateLimit int `json:"rate-limit"`
}
MethodsConfig type representing the config for each JSON-RPC method
Click to show internal directories.
Click to hide internal directories.